%% Instruction
% 1. Replace subject number for running this code for other subjects. For
% example, find and replace "subn" with "subn+1". 
% 2. "Electrode info" for all patients can be found in "info_channel.m".
% Replace this section with contents in "info_channel.m" for other
% patients. 

%% Initialize functions
addpath_recurse('chronux_2_12');
addpath_recurse('functions_general');

%%
load(fullfile('data_recording','sub1','nf_sub1.mat')); % substitue for other subjects
raw_voltage = nf_sub1; 

%% Electrode info (see instruction for other patients)
bad_channel = [4 9 11 14 16 17 22 25:27 30:32 36 39:42 47 49:52 57:66 74:86 92 96:99 102 106:111 113 114 116:121 124:131 133 136 ...
    141:143 145:146 150]; 
total_channel = 150;
good_channel = sort(setdiff(1:total_channel,bad_channel)); 
sr = 2048;

%%
load(fullfile('data_recording','sub1','trigger_info.mat'));
load(fullfile('data_recording','sub1','result_gamma','sub1_art_stroop.mat'));
load(fullfile('data_recording','sub1','result_theta','A02_theta_stroop_sub1.mat'));
load(fullfile('data_psychophysics','sub1','congruency_stroop'));
load(fullfile('data_psychophysics','sub1','vrt_stroop'));
load(fullfile('data_psychophysics','sub1','correct_stroop'));
load('t_trial.mat'); 



%% Analyze response aligned 
before_voice = sr*2.5;
after_voice = sr*2.5;
filter_space = sr; 
filter_space_after = sr*2;
normRange = sr/2; 

% sub1_thetaMax_stroop_in = cell(max(good_channel),1);
% sub1_thetaMax_stroop_con = cell(max(good_channel),1);
% sub1_thetaMean_stroop_con =cell(max(good_channel),1);
% sub1_thetaMean_stroop_in = cell(1,max(good_channel));

%
for i_channel = 34% change this to good_channel if you want to run the code for all the channels
    art = sub1_art_stroop{i_channel}; 
    %raw_voltage(i_channel,:) = ft_preproc_lowpassfilter(raw_voltage(i_channel,:),sr,300, 4, 'but');
    current = 1;
    correct_ind = 1; 
    for i = 1:height(trigger_info)
        if strcmp(trigger_info.task{i},'stroop') && strcmp(trigger_info.message{i},'stim_on')
            
            if  correct_stroop(correct_ind)==1 && ~ismember(correct_ind,art) 
                vrt =round(vrt_stroop(correct_ind)/1000*sr);
                vrt_sec(current) = vrt_stroop(correct_ind)/1000; 
                start = trigger_info.timestamp(i-1)-filter_space; 
                ending = trigger_info.timestamp(i+1)+filter_space; 
                trials_response{current} = raw_voltage(i_channel,start:ending); 
                
                
                
                base_start = trigger_info.timestamp(i-1)-filter_space; 
                base_end = trigger_info.timestamp(i-1)+normRange+filter_space; 
                base{current} = raw_voltage(i_channel,base_start:base_end); 
                
                trial_start  = trigger_info.timestamp(i)-filter_space;
                trial_end = trigger_info.timestamp(i+1)+filter_space;
                trials_stimAlign{current} = raw_voltage(i_channel,trial_start:trial_end);
                
                congruency(current) = congruency_stroop(correct_ind); 
                                
                
                current = current+1; 
                correct_ind = correct_ind+1; 
            else
                correct_ind = correct_ind+1; 
            end
        end
    end
    
    for i = 1:length(trials_response) 
        this_trial =  trials_response{i};
        params.fpass = [4 8]; params.err = [1 0.01]; % theoretical error bar 
        params.tapers = [2 3]; 
        params.movingwin = [0.5 0.01];
        this_trial = computeNormalizedFreqMag(this_trial',sr,params);
        this_trial = this_trial(93:400); 
        this_base = computeNormalizedFreqMag(base{i}',sr,params);
        this_base = this_base(93:144); 
        mean_base = mean(this_base); 
        this_trial = this_trial-mean_base; 
        this_trial = this_trial./std(this_base); 
        trials_matrix(i,:) = this_trial; 
    end
    A02_theta_stroop_sub1{i_channel} = trials_matrix;
    %trials_matrix = A02_theta_stroop_sub1{i_channel};

    con_ind = find(congruency==1); 
    incon_ind = find(congruency==-1);
    con_matrix = trials_matrix(con_ind,:); con_vrt = vrt_sec(con_ind); 
    incon_matrix = trials_matrix(incon_ind,:); incon_vrt = vrt_sec(incon_ind); 
    t_now = t_trial(93:end);
    t_now = t_now-(t_now(1)-(-0.5));  
    mean_vrt = nanmean(vrt_stroop); % in msec 
    [~,plot_start] = min(abs(t_now-(-0.5))); 
    [~,plot_end] = min(abs(t_now-2));  
    t_plot = t_now(plot_start:plot_end);
    con_matrix = con_matrix(:,plot_start:plot_end);
    incon_matrix = incon_matrix(:,plot_start:plot_end);

    [~,compare_start] = min(abs(t_plot-0)); 
    [~,compare_end] = min(abs(t_plot-mean_vrt/1000));   %in t_now
    
    mean_congruent = mean(con_matrix);
    mean_incongruent = mean(incon_matrix); 
    p = [];
    for i = compare_start:compare_end
        p(i) = permutationTest((con_matrix(:,i)),(incon_matrix(:,i)),5000); 
    end
    for i = 1:(length(p)-4)
        sum15(i) = sum(p(i:i+4));
    end
    p(1:compare_start-1) = NaN;
    p(compare_end+1:end) = NaN; 
    h = p;
    for i = 1:length(h)
        if h(i)<=0.01
            h(i)=1;
        else
            h(i)=0;
        end
    end
    sum15 = [];
    for i = 1:(length(h)-14)
        sum15(i) = sum(h(i:i+14));
    end
    start2 = strfind([0,sum15==15],[0 1]);
    end2 = strfind([sum15==15,0],[1 0]); end2 = end2+14;  
    if ismember(15,sum15)
        A02_ifStroop_theta_sub1(i_channel) = 1; % whether this electrode is conflict modulated
    else
        A02_ifStroop_theta_sub1(i_channel) = 0; 
    end   
    
    if max(mean_congruent(compare_start:compare_start+29))>=2&& max(mean_incongruent(compare_start:compare_start+29))>=2
        A02_visual_stroop_sub1(i_channel)=1; 
    else
        A02_visual_stroop_sub1(i_channel)=0;
    end

            
    sem_congruent = std(con_matrix)/sqrt(size(con_matrix,1)); 
    sem_incongruent = std(incon_matrix)/sqrt(size(incon_matrix,1)); 
    
%%     % Plot 
        figure(i_channel)
        ylimit = [-1 4];
        t = t_plot;
        if A02_ifStroop_theta_sub1(i_channel)==1
            for i = 1:length(start2)
                    a1 = t(start2(i));
                    a2 = t(end2(i));
                    rectangle('Position',[a1,ylimit(1)+0.05,a2-a1,ylimit(2)-ylimit(1)],'EdgeColor',[1 0.949 0.8 0.7],'FaceColor',[1 0.949 0.8 0.7])
                    hold on; 
            end
        end
        s1 = shadedErrorBar(t,mean_congruent,sem_congruent,'lineprops',{'-k'});
        set(s1.edge,'LineWidth',0.01)
        s1.mainLine.LineWidth = 2;
        hold on;
        s2 = shadedErrorBar(t,mean_incongruent,sem_incongruent,'lineprops',{'-r'});  
        set(s2.edge,'LineWidth',0.01)
        s2.mainLine.LineWidth = 2;
        xlim ([t(1) t(end)])
        ylim(ylimit) 
        xlabel('Time from stimulus (s)');
        ylabel('\theta power (z-scored)');  
        titleName = sprintf('stroop stim aligned');
        %title(titleName);  
        names = string([-0.4:0.4:2]);
        set(gca,'fontsize', 10,'xtick',[-0.4:0.4:2],'xticklabel',names,'TickDir','out','FontName','Arial')
        hold on; 
        line([mean_vrt/1000,mean_vrt/1000],[ylimit(1) ylimit(2)],'color','k','linestyle','--')
        legend1 = sprintf('C,n=%d',length(con_ind));
        legend2 = sprintf('I,n=%d',length(incon_ind));
        legend([s1.mainLine,s2.mainLine],{legend1,legend2},'FontSize',9,'Location','northwest','FontName','Arial');
        hold on; 
        saveName = sprintf('stroop_stim_aligned_sub1_channel%d',i_channel);
        %saveas(figure(i_channel),saveName,'jpeg')
        %close(figure(i_channel));
  
  
%%      
 
    
      clear con_matrix congruency incon_matrix trials_matrix trials_response base p sum15 type1_matrix ...
         type2_matrix type3_matrix start2 end2 type5_matrix type6_matrix type7_matrix type8_matrix type9_matrix trials_stimAlign 
end
% save('A02_ifStroop_theta_sub1.mat','A02_ifStroop_theta_sub1');
% save('A02_theta_stroop_sub1.mat','A02_theta_stroop_sub1');
% save('A02_visual_stroop_sub1.mat','A02_visual_stroop_sub1');


